==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicInternalFrameUI__24InternalFramePropertyChangeListener.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameUI$InternalFramePropertyChangeListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b6f388b0c7a0a50 javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$object	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$method$_init$05643df5b45f5094(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$object *, struct _jc_java_beans_PropertyChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$method_info$propertyChange$6d3500eaa79bf44b;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vmethods {
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$object *, struct _jc_java_beans_PropertyChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vmethods	javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$sub_refs	javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicInternalFrameUI__24InternalFramePropertyChangeListener.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameUI$InternalFramePropertyChangeListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b6f388b0c7a0a50 javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$object	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$method$_init$05643df5b45f5094(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$method_info$propertyChange$6d3500eaa79bf44b;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vmethods {
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vmethods	javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$sub_refs	javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24InternalFramePropertyChangeListener_H_ */
